@@ -101,6 +101,24 @@ dconf_settings_backend_signal (GDBusConnection *connection,
 
       g_free (rels);
     }
+
+  if (dconf_engine_decode_writability_notify (&path, interface_name,
+                                              signal_name, parameters))
+    {
+      GSettingsBackend *backend = G_SETTINGS_BACKEND (dcsb);
+
+      if (g_str_has_suffix (path, "/"))
+        {
+          g_settings_backend_path_writable_changed (backend, path);
+          g_settings_backend_path_changed (backend, path, NULL);
+        }
+
+      else
+        {
+          g_settings_backend_writable_changed (backend, path);
+          g_settings_backend_changed (backend, path, NULL);
+        }
+    }
 }
 
 static void
@@ -487,9 +505,7 @@ outstanding_watch_new (DConfSettingsBackend *dcsb,
                        const gchar          *name)
 {
   OutstandingWatch *watch;
-  gsize length;
 
-  length = strlen (name);
   watch = g_slice_new (OutstandingWatch);
   watch->dcsb = g_object_ref (dcsb);
   watch->state = dconf_engine_get_state (dcsb->engine);
@@ -520,6 +536,13 @@ add_match_done (GObject      *source,
   GError *error = NULL;
   GVariant *reply;
 
+  /* couldn't connect to DBus */
+  if (source == NULL)
+    {
+      outstanding_watch_free (watch);
+      return;
+    }
+
   reply = g_dbus_connection_call_finish (G_DBUS_CONNECTION (source),
                                          result, &error);
 
